@@ -922,6 +922,7 @@ void MainWindow::setInitialUrl(const KUrl& _url)
 
 void MainWindow::startSlideShow()
 {
+    d->mViewAction->trigger();
     // We need to wait until we have listed all images in the dirlister to
     // start the slideshow because the SlideShow objects needs an image list to
     // work.
@@ -1102,8 +1103,12 @@ void MainWindow::openDirUrl(const KUrl& url)
         // If currentPath is      "/home/user/photos/2008/event"
         // and wantedPath is      "/home/user/photos"
         // pathToSelect should be "/home/user/photos/2008"
-        const QString currentPath = QDir::cleanPath(currentUrl.toLocalFile(KUrl::RemoveTrailingSlash));
-        const QString wantedPath  = QDir::cleanPath(url.toLocalFile(KUrl::RemoveTrailingSlash));
+
+        // To anyone considering using KUrl::toLocalFile() instead of
+        // KUrl::path() here. Please don't, using KUrl::path() is the right
+        // thing to do here.
+        const QString currentPath = QDir::cleanPath(currentUrl.path(KUrl::RemoveTrailingSlash));
+        const QString wantedPath  = QDir::cleanPath(url.path(KUrl::RemoveTrailingSlash));
         const QChar separator('/');
         const int slashCount = wantedPath.count(separator);
         const QString pathToSelect = currentPath.section(separator, 0, slashCount + 1);
@@ -1389,6 +1394,9 @@ void MainWindow::toggleSlideShow()
     if (d->mSlideShow->isRunning()) {
         d->mSlideShow->stop();
     } else {
+        if (!d->mViewAction->isChecked()) {
+            d->mViewAction->trigger();
+        }
         if (!d->mFullScreenAction->isChecked()) {
             d->mFullScreenAction->trigger();
         }
@@ -1514,7 +1522,7 @@ void MainWindow::print()
 
 void MainWindow::preloadNextUrl()
 {
-    static bool disablePreload = qgetenv("GWENVIEW_MAX_UNREFERENCED_IMAGES") == "0";
+    static bool disablePreload = qgetenv("GV_MAX_UNREFERENCED_IMAGES") == "0";
     if (disablePreload) {
         kDebug() << "Preloading disabled";
         return;
