@@ -270,15 +270,19 @@ struct ViewMainPagePrivate
                          mSlideShow, SLOT(resumeAndGoToNextUrl()));
 
         mDocumentViews << view;
+        mActivityResources.insert(view, new KActivities::ResourceInstance(q->window()->winId(), view));
 
         return view;
     }
 
     void deleteDocumentView(DocumentView* view)
     {
-        mDocumentViewContainer->deleteView(view);
+        if (mDocumentViewController->view() == view) {
+            mDocumentViewController->setView(0);
+        }
         mDocumentViews.removeOne(view);
         mActivityResources.remove(view);
+        mDocumentViewContainer->deleteView(view);
     }
 
     void setupToolContainer()
@@ -342,6 +346,8 @@ struct ViewMainPagePrivate
         }
         if (oldView) {
             oldView->setCurrent(false);
+            Q_ASSERT(mActivityResources.contains(oldView));
+            mActivityResources[oldView]->notifyFocusedOut();
         }
         view->setCurrent(true);
         mDocumentViewController->setView(view);
@@ -354,13 +360,8 @@ struct ViewMainPagePrivate
         }
         mThumbnailBar->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Current);
 
-        if (mActivityResources.contains(oldView)) {
-            mActivityResources[oldView]->notifyFocusedOut();
-        }
-
-        if (mActivityResources.contains(view)) {
-            mActivityResources[view]->notifyFocusedIn();
-        }
+        Q_ASSERT(mActivityResources.contains(view));
+        mActivityResources[view]->notifyFocusedIn();
     }
 
     QModelIndex indexForView(DocumentView* view) const
@@ -667,7 +668,10 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
         it = viewForUrlMap.constBegin(),
         end = viewForUrlMap.constEnd();
     for (; it != end; ++it) {
-        it.value()->openUrl(it.key(), setup);
+        KUrl url = it.key();
+        DocumentView* view = it.value();
+        view->openUrl(url, setup);
+        d->mActivityResources[view]->setUri(url);
     }
 
     // Init views
@@ -678,18 +682,6 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
         } else {
             view->setCurrent(false);
         }
-
-        if (!d->mActivityResources.contains(view)) {
-            d->mActivityResources[view] = new KActivities::ResourceInstance(window()->winId(), view);
-        }
-
-        d->mActivityResources[view]->setUri(view->url());
-
-        if (view->url() == currentUrl) {
-            d->mActivityResources[view]->notifyFocusedIn();
-        } else {
-            d->mActivityResources[view]->notifyFocusedOut();
-        }
     }
 
     d->mSynchronizeCheckBox->setVisible(d->mCompareMode);
