@@ -26,8 +26,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QTreeView>
 
 // KDE
+#include <KAcceleratorManager>
 #include <KDebug>
-#include <KDialog>
 #include <KDirLister>
 #include <KDirModel>
 #include <KIconLoader>
@@ -143,7 +143,7 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
         QObject::connect(mSrcUrlButton, SIGNAL(clicked()), q, SLOT(setupSrcUrlTreeView()));
         QObject::connect(mSrcUrlButton, SIGNAL(clicked()), q, SLOT(toggleSrcUrlTreeView()));
         mSrcUrlTreeView->hide();
-        mSrcUrlTreeView->parentWidget()->layout()->setSpacing(0);
+        KAcceleratorManager::setNoAccel(mSrcUrlButton);
     }
 
     void setupDstUrlRequester()
@@ -284,7 +284,8 @@ void ThumbnailPage::openUrl(const KUrl& url)
     if (path.isEmpty() || path == "./") {
         text = d->mSrcBaseName;
     } else {
-        text = QString("%1/%2").arg(d->mSrcBaseName).arg(path);
+        path.replace("/", QString::fromUtf8(" › "));
+        text = QString::fromUtf8("%1 › %2").arg(d->mSrcBaseName).arg(path);
     }
     d->mSrcUrlButton->setText(text);
     d->mRecursiveDirModel->setUrl(url);
@@ -437,8 +438,6 @@ void ThumbnailPage::slotSrcUrlModelExpand(const QModelIndex& index)
 void ThumbnailPage::toggleSrcUrlTreeView()
 {
     d->mSrcUrlTreeView->setVisible(!d->mSrcUrlTreeView->isVisible());
-    QLayout* layout = d->mSrcUrlTreeView->parentWidget()->layout();
-    layout->setSpacing(d->mSrcUrlTreeView->isVisible() ? KDialog::spacingHint() : 0);
 }
 
 void ThumbnailPage::openUrlFromIndex(const QModelIndex& index)
